@@ -151,6 +151,7 @@ lsm.basis.lm = function(object, trms, xlev, grid, ...) {
 # (recover.data.lm works just fine)
 
 lsm.basis.mlm = function(object, trms, xlev, grid, ...) {
+    class(object) = c("mlm", "lm") # avoids error in vcov for "maov" objects
     bas = lsm.basis.lm(object, trms, xlev, grid, ...)
     bhat = coef(object)
     k = ncol(bhat)
@@ -168,7 +169,7 @@ lsm.basis.mlm = function(object, trms, xlev, grid, ...) {
 ### merMod objects (lme4 package)
 recover.data.merMod = function(object, ...) {
     if(!lme4::isLMM(object) && !lme4::isGLMM(object)) 
-        stop("Can't handle a nonlinear mixed model")
+        return("Can't handle a nonlinear mixed model")
     fcall = object@call
     recover.data(fcall, delete.response(terms(object)), 
                  attr(object@frame, "na.action"), ...)
@@ -230,38 +231,44 @@ lsm.basis.merMod = function(object, trms, xlev, grid, ...) {
 
 #--------------------------------------------------------------
 ### mer objects (from old lme4 version, now lme4.0)
-###!!! I commented this stuff out because of difficulties getting these past CRAN
+### re-enabled; CRAN check now seems to work with multiple add'l repositories
 
-# recover.data.mer = function(object, ...) {
-#     if(!lme4.0::isLMM(object) && !lme4.0::isGLMM(object)) 
-#         stop("Can't handle a nonlinear mixed model")
-#     fcall = object@call
-#     recover.data(fcall, delete.response(terms(object)), 
-#                  attr(object@frame, "na.action"), ...)
-# }
-# 
-# # Does NOT support pbkrtest capabilities. Uses asymptotic methods
-# lsm.basis.mer = function(object, trms, xlev, grid, ...) {
-#     V = as.matrix(vcov(object))
-#     dfargs = misc = list()
-#     if (lme4.0::isLMM(object)) {
-#         dffun = function(k, dfargs) NA        
-#     }
-#     else if (lme4.0::isGLMM(object)) {
-#         dffun = function(k, dfargs) NA
-#         misc = .std.link.labels(family(object), misc)
-#     }
-#     else 
-#         stop("Can't handle a nonlinear mixed model")
-#     
-#     contrasts = attr(object@X, "contrasts")
-#     m = model.frame(trms, grid, na.action = na.pass, xlev = xlev)
-#     X = model.matrix(trms, m, contrasts.arg = contrasts)
-#     bhat = lme4.0::fixef(object)
-#     nbasis=estimability::all.estble
-#     
-#     list(X=X, bhat=bhat, nbasis=nbasis, V=V, dffun=dffun, dfargs=dfargs, misc=misc)
-# }
+recover.data.mer = function(object, ...) {
+    if(!lme4.0::isLMM(object) && !lme4.0::isGLMM(object)) 
+        return("Can't handle a nonlinear mixed model")
+    fcall = object@call
+    recover.data(fcall, delete.response(terms(object)), 
+                 attr(object@frame, "na.action"), ...)
+}
+
+# Does NOT support pbkrtest capabilities. Uses asymptotic methods
+lsm.basis.mer = function(object, trms, xlev, grid, ...) {
+    V = as.matrix(vcov(object))
+    dfargs = misc = list()
+    if (lme4.0::isLMM(object)) {
+        dffun = function(k, dfargs) NA        
+    }
+    else if (lme4.0::isGLMM(object)) {
+        dffun = function(k, dfargs) NA
+        # need to work harder as there is no 'family' method
+        cfam = object@call$family
+        if (is.name(cfam))
+            fam = eval(cfam)()
+        else
+            fam = eval(cfam)
+        misc = .std.link.labels(fam, misc)
+    }
+    else 
+        stop("Can't handle a nonlinear mixed model")
+    
+    contrasts = attr(object@X, "contrasts")
+    m = model.frame(trms, grid, na.action = na.pass, xlev = xlev)
+    X = model.matrix(trms, m, contrasts.arg = contrasts)
+    bhat = lme4.0::fixef(object)
+    nbasis=estimability::all.estble
+    
+    list(X=X, bhat=bhat, nbasis=nbasis, V=V, dffun=dffun, dfargs=dfargs, misc=misc)
+}
 
 
 
@@ -611,39 +618,6 @@ lsm.basis.gam = function(object, trms, xlev, grid, ...) {
 # }
 
 
-
-
-
-#--------------------------------------------------------------
-#--------------------------------------------------------------
-#--------------------------------------------------------------
-#--------------------------------------------------------------
-### Public utility to use for obtaining an orthonormal basis nor nonestimable functions
-# Call with its QR decomp (LAPACK=FALSE), if available
-### --- Jan 27, 2015. Celebrating Mozart's 259th birthday
-### by moving the estimability stuff to a separate package --
-### 'estimability'
-# nonest.basis = function(qrX) {
-#     if (!is.qr(qrX))
-#         qrX = qr(qrX, LAPACK=FALSE)
-#     rank = qrX$rank
-#     tR = t(qr.R(qrX))
-#     p = nrow(tR)
-#     if (rank == p)
-#         return (matrix(NA))
-#     # null space of X is same as null space of R in QR decomp
-#     if (ncol(tR) < p) # add columns if not square
-#         tR = cbind(tR, matrix(0, nrow=p, ncol=p-ncol(tR)))
-#     # last few rows are zero -- add a diagonal of 1s
-#     extras = rank + seq_len(p - rank)
-#     for (j in extras) tR[j,j] = 1
-#     # nbasis is last p - rank cols of Q in QR decomp of tR
-#     nbasis = qr.Q(qr(tR))[ , extras, drop = FALSE]
-#     # permute the rows via pivot
-#     nbasis[qrX$pivot, ] = nbasis
-#     nbasis
-# }
-
 # Call this to do the standard stuff with link labels
 # Returns a modified misc
 .std.link.labels = function(fam, misc) {
